bayespy.inference.vmp.nodes.deterministic.Deterministic.lower_bound_contribution
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.deterministic

.. automethod:: Deterministic.lower_bound_contribution